@@ -4,7 +4,7 @@ Plotting large distributions
 
 """
 import seaborn as sns
-sns.set(style="whitegrid")
+sns.set_theme(style="whitegrid")
 
 diamonds = sns.load_dataset("diamonds")
 clarity_ranking = ["I1", "SI2", "SI1", "VS2", "VS1", "VVS2", "VVS1", "IF"]
