@@ -5,7 +5,7 @@ Plotting model residuals
 """
 import numpy as np
 import seaborn as sns
-sns.set(style="whitegrid")
+sns.set_theme(style="whitegrid")
 
 # Make an example dataset with y ~ x
 rs = np.random.RandomState(7)
@@ -13,4 +13,4 @@ x = rs.normal(2, 1, 75)
 y = 2 + 1.5 * x + rs.normal(0, 2, 75)
 
 # Plot the residuals after fitting a linear model
-sns.residplot(x, y, lowess=True, color="g")
+sns.residplot(x=x, y=y, lowess=True, color="g")
