@@ -742,7 +742,7 @@ class FacetGrid(Grid):
             plot_data = data_ijk[list(args)]
             if self._dropna:
                 plot_data = plot_data.dropna()
-            plot_args = [v for k, v in plot_data.iteritems()]
+            plot_args = [v for k, v in plot_data.items()]
 
             # Some matplotlib functions don't handle pandas objects correctly
             if func_module.startswith("matplotlib"):
@@ -949,7 +949,7 @@ class FacetGrid(Grid):
             Template for the row variable when titles are drawn on the grid
             margins. Must have {row_var} and {row_name} formatting keys.
         col_template:
-            Template for the row variable when titles are drawn on the grid
+            Template for the column variable when titles are drawn on the grid
             margins. Must have {col_var} and {col_name} formatting keys.
 
         Returns
