@@ -87,6 +87,7 @@ def _draw_figure(fig):
 
 def _default_color(method, hue, color, kws):
     """If needed, get a default color by using the matplotlib property cycle."""
+
     if hue is not None:
         # This warning is probably user-friendly, but it's currently triggered
         # in a FacetGrid context and I don't want to mess with that logic right now
@@ -95,12 +96,16 @@ def _default_color(method, hue, color, kws):
         #      warnings.warn(msg)
         return None
 
+    kws = kws.copy()
+    kws.pop("label", None)
+
     if color is not None:
         return color
 
     elif method.__name__ == "plot":
 
-        scout, = method([], [], scalex=False, scaley=False, **kws)
+        color = _normalize_kwargs(kws, mpl.lines.Line2D).get("color")
+        scout, = method([], [], scalex=False, scaley=False, color=color)
         color = scout.get_color()
         scout.remove()
 
@@ -694,6 +699,10 @@ def locator_to_legend_entries(locator, limits, dtype):
         formatter = mpl.ticker.LogFormatter()
     else:
         formatter = mpl.ticker.ScalarFormatter()
+        # Avoid having an offset/scientific notation which we don't currently
+        # have any way of representing in the legend
+        formatter.set_useOffset(False)
+        formatter.set_scientific(False)
     formatter.axis = dummy_axis()
 
     # TODO: The following two lines should be replaced
