@@ -12,15 +12,17 @@ from PIL import Image
 
 import pytest
 from pandas.testing import assert_frame_equal, assert_series_equal
-from numpy.testing import assert_array_equal
+from numpy.testing import assert_array_equal, assert_array_almost_equal
 
 from seaborn._core.plot import Plot, Default
-from seaborn._core.scales import Nominal, Continuous
-from seaborn._core.rules import categorical_order
+from seaborn._core.scales import Continuous, Nominal, Temporal
 from seaborn._core.moves import Move, Shift, Dodge
-from seaborn._stats.aggregation import Agg
+from seaborn._core.rules import categorical_order
+from seaborn._core.exceptions import PlotSpecError
 from seaborn._marks.base import Mark
 from seaborn._stats.base import Stat
+from seaborn._marks.dot import Dot
+from seaborn._stats.aggregation import Agg
 from seaborn.external.version import Version
 
 assert_vector_equal = functools.partial(
@@ -680,8 +682,9 @@ class TestPlotting:
     def test_empty(self):
 
         m = MockMark()
-        Plot().plot()
+        Plot().add(m).plot()
         assert m.n_splits == 0
+        assert not m.passed_data
 
     def test_no_orient_variance(self):
 
@@ -788,6 +791,12 @@ class TestPlotting:
             long_df, m, data_vars, split_vars, split_cols, split_keys
         )
 
+    def test_specified_width(self, long_df):
+
+        m = MockMark()
+        Plot(long_df, x="x", y="y").add(m, width="z").plot()
+        assert_array_almost_equal(m.passed_data[0]["width"], long_df["z"])
+
     def test_facets_no_subgroups(self, long_df):
 
         split_var = "col"
@@ -1080,7 +1089,7 @@ class TestPlotting:
 
         ax = mpl.figure.Figure().subplots()
         m = MockMark()
-        p = Plot().on(ax).add(m).plot()
+        p = Plot([1], [2]).on(ax).add(m).plot()
         assert m.passed_axes == [ax]
         assert p._figure is ax.figure
 
@@ -1089,7 +1098,7 @@ class TestPlotting:
 
         f = mpl.figure.Figure()
         m = MockMark()
-        p = Plot().on(f).add(m)
+        p = Plot([1, 2], [3, 4]).on(f).add(m)
         if facet:
             p = p.facet(["a", "b"])
         p = p.plot()
@@ -1106,7 +1115,7 @@ class TestPlotting:
         sf1, sf2 = mpl.figure.Figure().subfigures(2)
         sf1.subplots()
         m = MockMark()
-        p = Plot().on(sf2).add(m)
+        p = Plot([1, 2], [3, 4]).on(sf2).add(m)
         if facet:
             p = p.facet(["a", "b"])
         p = p.plot()
@@ -1242,6 +1251,54 @@ class TestPlotting:
             assert ax.get_title() == expected
 
 
+class TestExceptions:
+
+    def test_scale_setup(self):
+
+        x = y = color = ["a", "b"]
+        bad_palette = "not_a_palette"
+        p = Plot(x, y, color=color).add(MockMark()).scale(color=bad_palette)
+
+        msg = "Scale setup failed for the `color` variable."
+        with pytest.raises(PlotSpecError, match=msg) as err:
+            p.plot()
+        assert isinstance(err.value.__cause__, ValueError)
+        assert bad_palette in str(err.value.__cause__)
+
+    def test_coordinate_scaling(self):
+
+        x = ["a", "b"]
+        y = [1, 2]
+        p = Plot(x, y).add(MockMark()).scale(x=Temporal())
+
+        msg = "Scaling operation failed for the `x` variable."
+        with pytest.raises(PlotSpecError, match=msg) as err:
+            p.plot()
+        # Don't test the cause contents b/c matplotlib owns them here.
+        assert hasattr(err.value, "__cause__")
+
+    def test_semantic_scaling(self):
+
+        class ErrorRaising(Continuous):
+
+            def _setup(self, data, prop, axis=None):
+
+                def f(x):
+                    raise ValueError("This is a test")
+
+                new = super()._setup(data, prop, axis)
+                new._pipeline = [f]
+                return new
+
+        x = y = color = [1, 2]
+        p = Plot(x, y, color=color).add(Dot()).scale(color=ErrorRaising())
+        msg = "Scaling operation failed for the `color` variable."
+        with pytest.raises(PlotSpecError, match=msg) as err:
+            p.plot()
+        assert isinstance(err.value.__cause__, ValueError)
+        assert str(err.value.__cause__) == "This is a test"
+
+
 class TestFacetInterface:
 
     @pytest.fixture(scope="class", params=["row", "col"])
@@ -1384,6 +1441,17 @@ class TestFacetInterface:
                 assert all(shareset[shared].joined(root, ax) for ax in other)
                 assert not any(shareset[unshared].joined(root, ax) for ax in other)
 
+    def test_unshared_spacing(self):
+
+        x = [1, 2, 10, 20]
+        y = [1, 2, 3, 4]
+        col = [1, 1, 2, 2]
+
+        m = MockMark()
+        Plot(x, y).facet(col).add(m).share(x=False).plot()
+        assert_array_almost_equal(m.passed_data[0]["width"], [0.8, 0.8])
+        assert_array_equal(m.passed_data[1]["width"], [8, 8])
+
     def test_col_wrapping(self):
 
         cols = list("abcd")
@@ -2034,6 +2102,15 @@ class TestLegend:
         p = Plot(**xy, color=["a", "b", "c", "d"]).add(NoLegendMark()).plot()
         assert not p._figure.legends
 
+    def test_legend_has_no_offset(self, xy):
+
+        color = np.add(xy["x"], 1e8)
+        p = Plot(**xy, color=color).add(MockMark()).plot()
+        legend = p._figure.legends[0]
+        assert legend.texts
+        for text in legend.texts:
+            assert float(text.get_text()) > 1e7
+
 
 class TestDefaultObject:
 
