@@ -9,7 +9,7 @@ from numpy.testing import assert_array_equal
 
 from seaborn.external.version import Version
 from seaborn._core.rules import categorical_order
-from seaborn._core.scales import Nominal, Continuous
+from seaborn._core.scales import Nominal, Continuous, Boolean
 from seaborn._core.properties import (
     Alpha,
     Color,
@@ -52,8 +52,12 @@ class DataFixtures:
         return long_df["d"]
 
     @pytest.fixture
-    def vectors(self, num_vector, cat_vector):
-        return {"num": num_vector, "cat": cat_vector}
+    def bool_vector(self, long_df):
+        return long_df["x"] > 10
+
+    @pytest.fixture
+    def vectors(self, num_vector, cat_vector, bool_vector):
+        return {"num": num_vector, "cat": cat_vector, "bool": bool_vector}
 
 
 class TestCoordinate(DataFixtures):
@@ -195,7 +199,7 @@ class TestColor(DataFixtures):
 
     @pytest.mark.parametrize(
         "data_type,scale_class",
-        [("cat", Nominal), ("num", Continuous)]
+        [("cat", Nominal), ("num", Continuous), ("bool", Boolean)]
     )
     def test_default(self, data_type, scale_class, vectors):
 
@@ -213,18 +217,18 @@ class TestColor(DataFixtures):
         scale = Color().default_scale(x)
         assert isinstance(scale, Continuous)
 
-    # TODO default scales for other types
-
     @pytest.mark.parametrize(
         "values,data_type,scale_class",
         [
             ("viridis", "cat", Nominal),  # Based on variable type
             ("viridis", "num", Continuous),  # Based on variable type
+            ("viridis", "bool", Boolean),  # Based on variable type
             ("muted", "num", Nominal),  # Based on qualitative palette
             (["r", "g", "b"], "num", Nominal),  # Based on list palette
             ({2: "r", 4: "g", 8: "b"}, "num", Nominal),  # Based on dict palette
             (("r", "b"), "num", Continuous),  # Based on tuple / variable type
             (("g", "m"), "cat", Nominal),  # Based on tuple / variable type
+            (("c", "y"), "bool", Boolean),  # Based on tuple / variable type
             (get_colormap("inferno"), "num", Continuous),  # Based on callable
         ]
     )
@@ -234,12 +238,6 @@ class TestColor(DataFixtures):
         assert isinstance(scale, scale_class)
         assert scale.values == values
 
-    def test_inference_binary_data(self):
-
-        x = pd.Series([0, 0, 1, 0, 1], dtype=int)
-        scale = Color().infer_scale("viridis", x)
-        assert isinstance(scale, Nominal)
-
     def test_standardization(self):
 
         f = Color().standardize
@@ -266,26 +264,26 @@ class ObjectPropertyBase(DataFixtures):
     def unpack(self, x):
         return x
 
-    @pytest.mark.parametrize("data_type", ["cat", "num"])
+    @pytest.mark.parametrize("data_type", ["cat", "num", "bool"])
     def test_default(self, data_type, vectors):
 
         scale = self.prop().default_scale(vectors[data_type])
-        assert isinstance(scale, Nominal)
+        assert isinstance(scale, Boolean if data_type == "bool" else Nominal)
 
-    @pytest.mark.parametrize("data_type", ["cat", "num"])
+    @pytest.mark.parametrize("data_type", ["cat", "num", "bool"])
     def test_inference_list(self, data_type, vectors):
 
         scale = self.prop().infer_scale(self.values, vectors[data_type])
-        assert isinstance(scale, Nominal)
+        assert isinstance(scale, Boolean if data_type == "bool" else Nominal)
         assert scale.values == self.values
 
-    @pytest.mark.parametrize("data_type", ["cat", "num"])
+    @pytest.mark.parametrize("data_type", ["cat", "num", "bool"])
     def test_inference_dict(self, data_type, vectors):
 
         x = vectors[data_type]
         values = dict(zip(categorical_order(x), self.values))
         scale = self.prop().infer_scale(values, x)
-        assert isinstance(scale, Nominal)
+        assert isinstance(scale, Boolean if data_type == "bool" else Nominal)
         assert scale.values == values
 
     def test_dict_missing(self, cat_vector):
@@ -420,14 +418,14 @@ class TestFill(DataFixtures):
 
         x = vectors[data_type]
         scale = Fill().default_scale(x)
-        assert isinstance(scale, Nominal)
+        assert isinstance(scale, Boolean if data_type == "bool" else Nominal)
 
     @pytest.mark.parametrize("data_type", ["cat", "num", "bool"])
     def test_inference_list(self, data_type, vectors):
 
         x = vectors[data_type]
         scale = Fill().infer_scale([True, False], x)
-        assert isinstance(scale, Nominal)
+        assert isinstance(scale, Boolean if data_type == "bool" else Nominal)
         assert scale.values == [True, False]
 
     @pytest.mark.parametrize("data_type", ["cat", "num", "bool"])
@@ -436,7 +434,7 @@ class TestFill(DataFixtures):
         x = vectors[data_type]
         values = dict(zip(x.unique(), [True, False]))
         scale = Fill().infer_scale(values, x)
-        assert isinstance(scale, Nominal)
+        assert isinstance(scale, Boolean if data_type == "bool" else Nominal)
         assert scale.values == values
 
     def test_mapping_categorical_data(self, cat_vector):
@@ -486,6 +484,7 @@ class IntervalBase(DataFixtures):
     @pytest.mark.parametrize("data_type,scale_class", [
         ("cat", Nominal),
         ("num", Continuous),
+        ("bool", Boolean),
     ])
     def test_default(self, data_type, scale_class, vectors):
 
@@ -496,10 +495,13 @@ class IntervalBase(DataFixtures):
     @pytest.mark.parametrize("arg,data_type,scale_class", [
         ((1, 3), "cat", Nominal),
         ((1, 3), "num", Continuous),
+        ((1, 3), "bool", Boolean),
         ([1, 2, 3], "cat", Nominal),
         ([1, 2, 3], "num", Nominal),
+        ([1, 3], "bool", Boolean),
         ({"a": 1, "b": 3, "c": 2}, "cat", Nominal),
         ({2: 1, 4: 3, 8: 2}, "num", Nominal),
+        ({True: 4, False: 2}, "bool", Boolean),
     ])
     def test_inference(self, arg, data_type, scale_class, vectors):
 
