@@ -8,9 +8,11 @@ import pytest
 from numpy.testing import assert_array_equal
 from pandas.testing import assert_series_equal
 
+from seaborn._core.plot import Plot
 from seaborn._core.scales import (
     Nominal,
     Continuous,
+    Boolean,
     Temporal,
     PseudoAxis,
 )
@@ -90,6 +92,12 @@ class TestContinuous:
         s = Continuous((2, 3), (10, 100), "log")._setup(x, IntervalProperty())
         assert_array_equal(s(x), [1, 2, 3])
 
+    def test_interval_with_bools(self):
+
+        x = pd.Series([True, False, False])
+        s = Continuous()._setup(x, IntervalProperty())
+        assert_array_equal(s(x), [1, 0, 0])
+
     def test_color_defaults(self, x):
 
         cmap = color_palette("ch:", as_cmap=True)
@@ -448,7 +456,7 @@ class TestNominal:
     def test_color_unknown_palette(self, x):
 
         pal = "not_a_palette"
-        err = f"{pal} is not a valid palette name"
+        err = f"'{pal}' is not a valid palette name"
         with pytest.raises(ValueError, match=err):
             Nominal(pal)._setup(x, Color())
 
@@ -555,6 +563,28 @@ class TestNominal:
         s = Nominal((2, 4))._setup(x, MockProperty())
         assert_array_equal(s(x), [4, np.sqrt(10), 2, np.sqrt(10)])
 
+    def test_empty_data(self):
+
+        x = pd.Series([], dtype=object, name="x")
+        s = Nominal()._setup(x, Coordinate())
+        assert_array_equal(s(x), [])
+
+    @pytest.mark.skipif(
+        Version(mpl.__version__) < Version("3.4.0"),
+        reason="Test failing on older matplotlib for unclear reasons",
+    )
+    def test_finalize(self, x):
+
+        ax = mpl.figure.Figure().subplots()
+        s = Nominal()._setup(x, Coordinate(), ax.yaxis)
+        s._finalize(Plot(), ax.yaxis)
+
+        levels = x.unique()
+        assert ax.get_ylim() == (len(levels) - .5, -.5)
+        assert_array_equal(ax.get_yticks(), list(range(len(levels))))
+        for i, expected in enumerate(levels):
+            assert ax.yaxis.major.formatter(i) == expected
+
 
 class TestTemporal:
 
@@ -658,3 +688,138 @@ class TestTemporal:
         Temporal().label(concise=True)._setup(t, Coordinate(), ax.xaxis)
         formatter = ax.xaxis.get_major_formatter()
         assert isinstance(formatter, mpl.dates.ConciseDateFormatter)
+
+
+class TestBoolean:
+
+    @pytest.fixture
+    def x(self):
+        return pd.Series([True, False, False, True], name="x", dtype=bool)
+
+    def test_coordinate(self, x):
+
+        s = Boolean()._setup(x, Coordinate())
+        assert_array_equal(s(x), x.astype(float))
+
+    def test_coordinate_axis(self, x):
+
+        ax = mpl.figure.Figure().subplots()
+        s = Boolean()._setup(x, Coordinate(), ax.xaxis)
+        assert_array_equal(s(x), x.astype(float))
+        f = ax.xaxis.get_major_formatter()
+        assert f.format_ticks([0, 1]) == ["False", "True"]
+
+    @pytest.mark.parametrize(
+        "dtype,value",
+        [
+            (object, np.nan),
+            (object, None),
+            # TODO add boolean when we don't need the skipif below
+        ]
+    )
+    def test_coordinate_missing(self, x, dtype, value):
+
+        x = x.astype(dtype)
+        x[2] = value
+        s = Boolean()._setup(x, Coordinate())
+        assert_array_equal(s(x), x.astype(float))
+
+    @pytest.mark.skipif(
+        # TODO merge into test above when removing
+        Version(pd.__version__) < Version("1.0.0"),
+        reason="Test requires nullable booleans",
+    )
+    def test_coordinate_with_pd_na(self, x):
+
+        x = x.astype("boolean")
+        x[2] = pd.NA
+        s = Boolean()._setup(x, Coordinate())
+        assert_array_equal(s(x), x.astype(float))
+
+    def test_color_defaults(self, x):
+
+        s = Boolean()._setup(x, Color())
+        cs = color_palette()
+        expected = [cs[int(x_i)] for x_i in ~x]
+        assert_array_equal(s(x), expected)
+
+    def test_color_list_palette(self, x):
+
+        cs = color_palette("crest", 2)
+        s = Boolean(cs)._setup(x, Color())
+        expected = [cs[int(x_i)] for x_i in ~x]
+        assert_array_equal(s(x), expected)
+
+    def test_color_tuple_palette(self, x):
+
+        cs = tuple(color_palette("crest", 2))
+        s = Boolean(cs)._setup(x, Color())
+        expected = [cs[int(x_i)] for x_i in ~x]
+        assert_array_equal(s(x), expected)
+
+    def test_color_dict_palette(self, x):
+
+        cs = color_palette("crest", 2)
+        pal = {True: cs[0], False: cs[1]}
+        s = Boolean(pal)._setup(x, Color())
+        expected = [pal[x_i] for x_i in x]
+        assert_array_equal(s(x), expected)
+
+    def test_object_defaults(self, x):
+
+        vs = ["x", "y", "z"]
+
+        class MockProperty(ObjectProperty):
+            def _default_values(self, n):
+                return vs[:n]
+
+        s = Boolean()._setup(x, MockProperty())
+        expected = [vs[int(x_i)] for x_i in ~x]
+        assert s(x) == expected
+
+    def test_object_list(self, x):
+
+        vs = ["x", "y"]
+        s = Boolean(vs)._setup(x, ObjectProperty())
+        expected = [vs[int(x_i)] for x_i in ~x]
+        assert s(x) == expected
+
+    def test_object_dict(self, x):
+
+        vs = {True: "x", False: "y"}
+        s = Boolean(vs)._setup(x, ObjectProperty())
+        expected = [vs[x_i] for x_i in x]
+        assert s(x) == expected
+
+    def test_fill(self, x):
+
+        s = Boolean()._setup(x, Fill())
+        assert_array_equal(s(x), x)
+
+    def test_interval_defaults(self, x):
+
+        vs = (1, 2)
+
+        class MockProperty(IntervalProperty):
+            _default_range = vs
+
+        s = Boolean()._setup(x, MockProperty())
+        expected = [vs[int(x_i)] for x_i in x]
+        assert_array_equal(s(x), expected)
+
+    def test_interval_tuple(self, x):
+
+        vs = (3, 5)
+        s = Boolean(vs)._setup(x, IntervalProperty())
+        expected = [vs[int(x_i)] for x_i in x]
+        assert_array_equal(s(x), expected)
+
+    def test_finalize(self, x):
+
+        ax = mpl.figure.Figure().subplots()
+        s = Boolean()._setup(x, Coordinate(), ax.xaxis)
+        s._finalize(Plot(), ax.xaxis)
+        assert ax.get_xlim() == (1.5, -.5)
+        assert_array_equal(ax.get_xticks(), [0, 1])
+        assert ax.xaxis.major.formatter(0) == "False"
+        assert ax.xaxis.major.formatter(1) == "True"
